abacusai.dataset_column — AbacusAI documentation

# `abacusai.dataset_column`

## Module Contents

### Classes

`DatasetColumn` | A schema description for a column

class abacusai.dataset_column.DatasetColumn(client, name=None, dataType=None, detectedDataType=None, featureType=None, detectedFeatureType=None, originalName=None, validDataTypes=None, timeFormat=None, timestampFrequency=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A schema description for a column

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The unique name of the column.

    - dataType (str) – The underlying data type of each column: INTEGER, FLOAT, STRING, DATE, DATETIME, BOOLEAN, LIST, STRUCT, NULL. Refer to the (guide on data types)[https://api.abacus.ai/app/help/class/DataType] for more information.

    - detectedDataType (str) – The detected data type of the column

    - featureType (str) – Feature Type of the column

    - detectedFeatureType (str) – The detected feature type of the column

    - originalName (str) – The original name of the column

    - validDataTypes (list of enum string) – The valid data type options for this column

    - timeFormat (str) – The detected time format of the column

    - timestampFrequency (str) – The detected frequency of the timestamps in the dataset

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict